:mod:`whisk.model_stub`
=======================

.. py:module:: whisk.model_stub


Module Contents
---------------


.. py:class:: ModelStub

   A placeholder for a real ML Model. Returns the number of features in each row.

   Example:

       ModelStub().predict([[1,2],[3,4]]) => [2,2]

   .. method:: predict(self, X)



